<?php
namespace Teknisa\PLA\Modules\Cardapio\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;

class Pla02600 extends \Zeedhi\Framework\Controller\Report {

    protected $birtStrategy;
    protected $crudService;
    protected $environment;
    protected $fileServerFilesUrl;

    public function __construct($reportService, $birtStrategy, $crudService, $parameterBag, $environment, $fileServerFilesUrl) {
        $this->reportService = $reportService;
        $this->birtStrategy   = $birtStrategy;
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->environment = $environment;
        $this->fileServerFilesUrl = $fileServerFilesUrl;
    }

    protected $reportMapping = array (
        'pla02600' =>
            array (
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array (
                        'CDFILIAL'      => 'CDFILIAL',
                        'SEMANAINICIAL' => 'DTINICIAL',
                        'SEMANAFINAL'   => 'DTFINAL',
                        'CDDIETA'       => 'CDDIETA',
                        'NRORG'         => 'NRORG',
                        'CDSERVFILI'    => 'LISTASERVICO',
                        'IMPCOMENSAIS'  => 'IMPCOMENS',
                        'QUEBRARPAG'    => 'QUEBRARPAG',
                        'AGRUPAR'       => 'AGRUPAR',
                        'IMPMENSAGEM'   => 'IMPMENSAGEM',
                        'IMPNMFANTASIA' => 'IMPNMFANTASIA',
                        'QUEBRAMES'     => 'QUEBRAMES',
                        'WEEK_DAYS_CONCAT' => 'WEEK_DAYS',
                        'FILESERVER'    =>  'FILESERVER',
                        'P_CDFILIPROC'  => 'P_CDFILIPROC'
                    ),
            ),
        'pla02602' =>
            array (
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array (
                        'CDFILIAL'      => 'CDFILIAL',
                        'SEMANAINICIAL' => 'DTINICIAL',
                        'SEMANAFINAL'   => 'DTFINAL',
                        'CDDIETA'       => 'CDDIETA',
                        'NRORG'         => 'NRORG',
                        'CDSERVFILI'    => 'LISTASERVICO',
                        'IMPCOMENSAIS'  => 'IMPCOMENS',
                        'QUEBRARPAG'    => 'QUEBRARPAG',
                        'AGRUPAR'       => 'AGRUPAR',
                        'IMPMENSAGEM'   => 'IMPMENSAGEM',
                        'IMPNMFANTASIA' => 'IMPNMFANTASIA',
                        'QUEBRAMES'     => 'QUEBRAMES',
                        'NRTIPOCUSTO'   => 'NRTIPOCUSTO',
                        'TPDATA'        => 'TPDATA'
                    ),
            ),
        'pla02603' =>
            array (
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array (
                        'CDFILIAL'      => 'CDFILIAL',
                        'SEMANAINICIAL' => 'DTINICIAL',
                        'SEMANAFINAL'   => 'DTFINAL',
                        'CDDIETA'       => 'CDDIETA',
                        'NRORG'         => 'NRORG',
                        'CDSERVFILI'    => 'LISTASERVICO',
                        'IMPCOMENSAIS'  => 'IMPCOMENS',
                        'QUEBRARPAG'    => 'QUEBRARPAG',
                        'AGRUPAR'       => 'AGRUPAR',
                        'IMPMENSAGEM'   => 'IMPMENSAGEM',
                        'IMPNMFANTASIA' => 'IMPNMFANTASIA',
                        'QUEBRAMES'     => 'QUEBRAMES',
                        'WEEK_DAYS_CONCAT' => 'WEEK_DAYS',
                        'FILESERVER'    =>  'FILESERVER',
                        'P_CDFILIPROC'  => 'P_CDFILIPROC'
                    ),
            ),
    );

    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $row['NRORG'] = $this->environment->getNrOrg();
        $row['P_CDFILIPROC'] = $this->environment->getCdFilial();
        $row['FILESERVER'] = $this->fileServerFilesUrl;
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
    }

    public function consultaConfigCardapio(DTO\Request\Filter $request, DTO\Response $response){
        $dataSourceName = "pla02600_consulta_config_cardapio";
        $parameterBagColumns = array('CDFILIAL',  'CDSERVFILI', 'DTINICIAL', 'DTFINAL', 'NRORG');

        try {
            $filterCriteria = $request->getFilterCriteria();
            $filterCriteria->setDataSourceName($dataSourceName);
            $filterCriteria = $this->crudService->getFilterCriteriaWithNrOrg($filterCriteria);
            $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $parameterBagColumns);
            $this->crudService->find($response, $newFilterCriteria);
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 500));
        }
    }
    function printParams($report, $row){
        $struct = $this->reportMapping[$report]['parameterMapping'];
        $str = "\n";
        foreach($struct as $key => $value){
            $str .= str_pad($value, 18, ".", STR_PAD_RIGHT) . str_pad($row[$key], 20, ".", STR_PAD_LEFT)."\n";
    
        }
         var_dump($str);die;
    }




}