<?php
namespace Teknisa\PLA\Modules\Medicao\Services;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class Pla10200RetiradaPlanejamentoInventarioService {

	protected $util;
    protected $dataSourceManager;
    protected $environment;
    protected $entityManager;
    protected $novoCodigo;
    protected $connection;
    protected $validacoesEstoqueService;

	public function __construct($util, $dataSourceManager, $environment, $entityManager, $novoCodigo, $validacoesEstoqueService) {
        $this->util = $util;
        $this->environment = $environment;
        $this->entityManager = $entityManager;
		$this->connection = $entityManager->getConnection();
		$this->novoCodigo = $novoCodigo;
		$this->validacoesEstoqueService = $validacoesEstoqueService;
	}

    public function iniciaConexao() {
        $this->connection->beginTransaction();
    }

    public function realizaCommit() {
        if($this->connection->isTransactionActive())
            $this->connection->commit();
    }

    public function realizaRollback() {
        if($this->connection->isTransactionActive())
            $this->connection->rollback();
    }
    
    public function executaProcedureRetiradaInventarioPla($row){
        $cdoperador = $this->environment->getCdOperador();
        $nrorg = $this->environment->getNrOrg();

        $procedureConsumoPlanejado = new StoredProcedure($this->connection, 'RETIRADA_INVENTARIO_PLA');
        $procedureConsumoPlanejado->addParam(new Param('P_CDFILIAL',          Param::PARAM_INPUT,  $row['CDFILIAL'],          Param::PARAM_TYPE_STR));
        $procedureConsumoPlanejado->addParam(new Param('P_NRINVRETIPLA',      Param::PARAM_INPUT,  $row['NRINVRETIPLA'],      Param::PARAM_TYPE_STR));
        $procedureConsumoPlanejado->addParam(new Param('P_GRAVAR_ZERAR',      Param::PARAM_INPUT,  $row['GRAVAR_ZERAR'],      Param::PARAM_TYPE_STR));
        $procedureConsumoPlanejado->addParam(new Param('P_CONTINUA_SEM_EFET', Param::PARAM_INPUT,  $row['CONTINUA_SEM_EFET'], Param::PARAM_TYPE_STR));
        $procedureConsumoPlanejado->addParam(new Param('P_CDOPERADOR',        Param::PARAM_INPUT,  $cdoperador,               Param::PARAM_TYPE_STR));
        $procedureConsumoPlanejado->addParam(new Param('P_NRORG',             Param::PARAM_INPUT,  $nrorg,                    Param::PARAM_TYPE_STR));
        $procedureConsumoPlanejado->addParam(new Param('P_RETORNO',           Param::PARAM_OUTPUT, null,                      Param::PARAM_TYPE_STR, 30));
        $procedureConsumoPlanejado->addParam(new Param('P_LISTAERROS',        Param::PARAM_OUTPUT, null,                      Param::PARAM_TYPE_INT, 20));

        $result = $procedureConsumoPlanejado->execute();
        
        return $result;
    }
    
    public function retornaPeriodoRetiradaInventario($row){
        $sql = 'SELECT TRUNC(DTINIRETIPLA) AS DTINICIAL, TRUNC(DTFINRETIPLA) AS DTFINAL FROM INVENTRETIPLA WHERE CDFILIAL = :CDFILIAL AND NRINVRETIPLA = :NRINVRETIPLA';
        $params = array(
            'CDFILIAL' => $row['CDFILIAL'],
            'NRINVRETIPLA' => $row['NRINVRETIPLA']
        );
        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
        return $stmt->fetch(\PDO::FETCH_ASSOC);
    }

    public function retornaRetiradasPeriodo($row){
        $rowInventario = $this->retornaPeriodoRetiradaInventario($row);
        $sql = "SELECT RE.CDFILIAL,  RE.NRLANCESTQ,
               TO_CHAR(RE.DTRETIRADA, 'DD/MM/YYYY') AS DTRETIRADA,
               S.CDSERVFILI, S.NMSERVICO
          FROM RETIRADA RE
               INNER JOIN CARDADIA CA ON CA.CDFILIAL = RE.CDFILIAL AND
                                         CA.NRCARDAPIO = RE.NRCARDAPIO
               LEFT JOIN SERVICO S ON S.CDFILIAL = CA.CDFILIAL AND S.CDSERVFILI = CA.CDSERVFILI
         WHERE RE.CDFILIAL = :CDFILIAL
         AND CA.DTCARDAPIO BETWEEN :DTINICIAL AND :DTFINAL";
        
        $params = array(
            'DTINICIAL' => $rowInventario['DTINICIAL'],
            'DTFINAL'   => $rowInventario['DTFINAL'],
            'CDFILIAL'  => $row['CDFILIAL']
        );
        
        $pstmt = $this->connection->prepare($sql);
        $pstmt->execute($params);
        return $pstmt->fetchAll(\PDO::FETCH_ASSOC);
    }
    
    public function executaAtualizacaoEstoque($row){
        $this->validacoesEstoqueService->atualizaEstoque($row['CDFILIAL'], $row['NRLANCESTQ']);
    }
    
    //converte a mensagem retornando um array formatado com os parametros necessários ou uma string com o erro puro
    public function converter($message){
		$messageUpper 	= strtoupper($message);
		$codeStart	 	= strpos($messageUpper, "_MSGSTA_");
		$codeEnd		= strpos($messageUpper, "_MSGEND_");
		
		if ($codeStart !== FALSE && $codeEnd !== FALSE){
			$msgStart = $codeStart + strlen("_MSGSTA_");
			$msgEnd = $codeEnd - $msgStart;

	        $paramstring = substr($message, $msgStart, $msgEnd);
	        $params = explode("$$", $paramstring);
	        
            $mensagem = array_shift($params);
	        
	        $resultado = array("MSGCODE"=>$mensagem);
	        $resultado['PARAMS'] = array();
	        
	        if(sizeof($params) > 0){
	            $parametros = array();
	            foreach ($params as $index => $value) {
	                 $parametros['PARAM'.$index] = $value;
	            }
	            $resultado['PARAMS'] = $parametros;
	        }
	        
	        return $resultado;
		}
		return $message;
	}
	
	public function getMessageErrorList($cdfilial, $nrlista){
	    $sql = 'SELECT DSERRO FROM LISTAERROS WHERE NRLISTA = :NRLISTA AND CDFILIAL = :CDFILIAL';
	    $params = array(
	        'CDFILIAL' => $cdfilial,
	        'NRLISTA'  => $nrlista
	    );
	    $pstmt = $this->connection->prepare($sql);
	    $pstmt->execute($params);
	    return $pstmt->fetchAll(\PDO::FETCH_ASSOC);
	}

}