<?php
namespace Teknisa\PLA\Modules\Transportadas\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Pla04100ServicosTransportados {
    
	protected $connection;
	protected $environment;
	protected $util;

	public function __construct($connection, $environment, $util) {
		$this->connection    = $connection;
		$this->environment   = $environment;
		$this->util          = $util;
	}
    
    public function returnComensais(DTO\Request\Row $request, DTO\Response $response) {
    	$row = $request->getRow();

    	$sql = "SELECT SUM(QTCOMESTICAR) QTCOMESTICAR FROM CARDADIA WHERE CDFILIAL = :P_CDFILIAL AND CDSERVFILI = :P_CDSERVFILI AND DTCARDAPIO = :P_DTCARDAPIO";
	
		$params = array(
			"P_CDFILIAL"   => $row['CDFILIAL'],
			"P_CDSERVFILI" => $row['CDSERVFILI'],
			"P_DTCARDAPIO" => $row["DTSERVTRAN"]
		);
		
		$stmt = $this->connection->prepare($sql);
		$stmt->execute($params);
    	$result = $stmt->fetchAll();
		$response->addDataSet(new DataSet("result", $result));
    }
    
    public function calculate(DTO\Request\Row $request, DTO\Response $response) {
    	$row = $request->getRow();
    	$nrorg = $this->environment->getNrOrg();
    	$cdoperador = $this->environment->getCdOperador();
    	$concat = '';
		$filiServ = '';
		$filiServConcat = [];
    	if ($row['TODOS_SERV'] == 'N') {
    		foreach($row['NMSERVICO_CALC'] as $serv)  {
	            $concat .= $row['UNIDADE'].$serv.'_'; 
	        }
	        $filiServ = explode("_", $concat);
	        array_pop($filiServ);
    	} else {
			$sql = "SELECT SUBSTR(S.CDFILIAL || S.CDSERVFILI, 1, 9) AS FILISERV FROM SERVICO S, FILIOPER F WHERE S.CDFILIAL = :CDFILIAL AND((INSTR(:CDGRUPSERV, S.CDGRUPSERV) <> 0) OR (:CDGRUPSERV = 'T')) AND (F.CDOPERADOR = :CDOPERADOR) AND (F.CDFILIAL = S.CDFILIAL) AND (S.NRORG = :NRORG) ORDER BY NLSSORT(S.CDFILIAL,'NLS_SORT=BINARY_AI') , NLSSORT(S.CDSERVFILI,'NLS_SORT=BINARY_AI')";
			
			$params = array(
				"CDOPERADOR"   => $cdoperador,
				"NRORG" => $nrorg,
				"CDFILIAL" => $row['UNIDADE'],
				"CDGRUPSERV" => 'T'
			);
			
			$stmt = $this->connection->prepare($sql);
			$stmt->execute($params);
	    	$result = $stmt->fetchAll();
			foreach($result as $unServ) {
		        array_push($filiServConcat, $unServ['FILISERV']);
			}
		    $filiServ = $filiServConcat;
	    }

	    $nrlistaserv = $this->util->insertLista($filiServ);
	    $this->procedureServTransp($nrlistaserv, $row, $cdoperador);
    }
    
    public function calculateNotFoundRegister(DTO\Request\Row $request, DTO\Response $response) {
    	$row = $request->getRow();
    	$nrorg = $this->environment->getNrOrg();
    	$cdoperador = $this->environment->getCdOperador();
    	
    	$row['UNIDADE'] = $row['CDFILIAL'];
    	$row['DTSERVTRAN_CALC'] = $row['DTSERVTRAN'];
    	
    	$concat = $row['CDFILIAL'].$row['CDSERVFILI']; 
    	$filiServ = explode("_", $concat);
    	
	    $nrlistaserv = $this->util->insertLista($filiServ);
	    $this->procedureServTransp($nrlistaserv, $row, $cdoperador);
    }
    
    public function procedureServTransp($nrlistaserv, $row, $cdoperador) {
    	$today = date("d/m/Y G:i:s");

    	//$connection = $this->entityManager->getConnection();
    	$procedure = new StoredProcedure($this->connection, 'SERVICOS_TRANSPORTADOS');
    	
    	$procedure->addParam(new Param('P_CDFILIAL',   Param::PARAM_INPUT, $row['UNIDADE'],         Param::PARAM_TYPE_STR));
    	$procedure->addParam(new Param('P_SERVICOS',   Param::PARAM_INPUT, $nrlistaserv,            Param::PARAM_TYPE_STR));
    	$procedure->addParam(new Param('P_DTINICIAL',  Param::PARAM_INPUT, $row['DTSERVTRAN_CALC'], Param::PARAM_TYPE_STR));
    	$procedure->addParam(new Param('P_DTFINAL',    Param::PARAM_INPUT, $row['DTSERVTRAN_CALC'], Param::PARAM_TYPE_STR));
    	$procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $cdoperador,             Param::PARAM_TYPE_STR));
    	$procedure->addParam(new Param('P_DTHRCALCST', Param::PARAM_INPUT, $today,                  Param::PARAM_TYPE_STR));
    	$procedure->execute();
    	$this->util->deleteLista($nrlistaserv);
    }

}